@@ -1,19 +1,25 @@
+from typing import TYPE_CHECKING
+
 import numpy as np
-import pandas as pd
-from pandas.api.types import is_numeric_dtype
 
 from .. import util
 from ..dimension import Dimension, dimension_name
 from ..element import Element
 from ..ndmapping import NdMapping, item_check, sorted_context
-from ..util import PANDAS_GE_2_1_0
+from ..util import dtype_kind
+from ..util.dependencies import PANDAS_GE_2_1_0, _LazyModule
 from .interface import DataError, Interface
 from .util import finite_range
 
+if TYPE_CHECKING:
+    import pandas as pd
+else:
+    pd = _LazyModule("pandas")
+
+
 
 class PandasAPI:
-    """
-    This class is used to describe the interface as having a pandas-like API.
+    """This class is used to describe the interface as having a pandas-like API.
 
     The reason to have this class is that it is not always
     possible to directly inherit from the PandasInterface.
@@ -21,15 +27,26 @@ class PandasAPI:
     This class should not have any logic as it should be used like:
         if issubclass(interface, PandasAPI):
             ...
+
     """
 
 
 class PandasInterface(Interface, PandasAPI):
 
-    types = (pd.DataFrame,)
-
     datatype = 'dataframe'
 
+    @classmethod
+    def loaded(cls):
+        # 2025-02: As long as it is a required dependency and to not break
+        # existing behavior we will for now always return True
+        return bool(pd)
+
+    @classmethod
+    def applies(cls, obj):
+        if not cls.loaded():
+            return False
+        return type(obj) is pd.DataFrame or type(obj) is pd.Series
+
     @classmethod
     def dimension_type(cls, dataset, dim):
         return cls.dtype(dataset, dim).type
@@ -105,8 +122,8 @@ class PandasInterface(Interface, PandasAPI):
                                     "per dimension or a mapping between key and value dimension "
                                     "values.")
                 column_data = zip(*((util.wrap_tuple(k)+util.wrap_tuple(v))
-                                    for k, v in column_data))
-                data = dict(((c, col) for c, col in zip(columns, column_data)))
+                                    for k, v in column_data), strict=None)
+                data = dict(((c, col) for c, col in zip(columns, column_data, strict=None)))
             elif isinstance(data, np.ndarray):
                 if data.ndim == 1:
                     if eltype._auto_indexable_1d and len(kdims)+len(vdims)>1:
@@ -126,7 +143,7 @@ class PandasInterface(Interface, PandasAPI):
                                     f'at least {min_dims} columns but found only {len(data)} columns.')
                 elif not cls.expanded(data):
                     raise ValueError('PandasInterface expects data to be of uniform shape.')
-                data = pd.DataFrame(dict(zip(columns, data)), columns=columns)
+                data = pd.DataFrame(dict(zip(columns, data, strict=None)), columns=columns)
             elif ((isinstance(data, dict) and any(c not in data for c in columns)) or
                   (isinstance(data, list) and any(isinstance(d, dict) and c not in d for d in data for c in columns))):
                 raise ValueError('PandasInterface could not find specified dimensions in the data.')
@@ -193,7 +210,7 @@ class PandasInterface(Interface, PandasAPI):
             column = cls.index_values(dataset, dimension)
         else:
             column = dataset.data[dimension.name]
-        if column.dtype.kind == 'O':
+        if dtype_kind(column) == 'O':
             if not isinstance(dataset.data, pd.DataFrame):
                 column = column.sort(inplace=False)
             else:
@@ -211,7 +228,7 @@ class PandasInterface(Interface, PandasAPI):
             if dimension.nodata is not None:
                 column = cls.replace_value(column, dimension.nodata)
             cmin, cmax = finite_range(column, column.min(), column.max())
-            if column.dtype.kind == 'M' and getattr(column.dtype, 'tz', None):
+            if dtype_kind(column) == 'M' and getattr(column.dtype, 'tz', None):
                 return (cmin.to_pydatetime().replace(tzinfo=None),
                         cmax.to_pydatetime().replace(tzinfo=None))
             return cmin, cmax
@@ -227,7 +244,7 @@ class PandasInterface(Interface, PandasAPI):
         dataframes = []
         for key, ds in datasets:
             data = ds.data.copy()
-            for d, k in zip(dimensions, key):
+            for d, k in zip(dimensions, key, strict=None):
                 data[d.name] = k
             dataframes.append(data)
         return cls.concat_fn(dataframes)
@@ -289,8 +306,9 @@ class PandasInterface(Interface, PandasAPI):
                     c for c in reindexed.columns if c not in cols
                 ]
             else:
+                from pandas.api.types import is_numeric_dtype
                 numeric_cols = [
-                    c for c, d in zip(reindexed.columns, reindexed.dtypes)
+                    c for c, d in zip(reindexed.columns, reindexed.dtypes, strict=None)
                     if is_numeric_dtype(d) and c not in cols
                 ]
             groupby_kwargs = {"sort": False}
@@ -300,7 +318,7 @@ class PandasInterface(Interface, PandasAPI):
             df = grouped[numeric_cols].aggregate(fn, **kwargs).reset_index()
         else:
             agg = reindexed.apply(fn, **kwargs)
-            data = {col: [v] for col, v in zip(agg.index, agg.values)}
+            data = {col: [v] for col, v in zip(agg.index, agg.values, strict=None)}
             df = pd.DataFrame(data, columns=list(agg.index))
 
         dropped = []
@@ -312,9 +330,9 @@ class PandasInterface(Interface, PandasAPI):
 
     @classmethod
     def unpack_scalar(cls, dataset, data):
-        """
-        Given a dataset object and data in the appropriate format for
+        """Given a dataset object and data in the appropriate format for
         the interface, return a simple scalar.
+
         """
         if len(data) != 1 or len(data.columns) > 1:
             return data
@@ -409,7 +427,7 @@ class PandasInterface(Interface, PandasAPI):
                     index_sel = {}
             column_sel = {k: v for k, v in selection.items() if k not in index_sel}
             if column_sel:
-                selection_mask = cls.select_mask(dataset, column_sel)
+                selection_mask = cls.select_mask(dataset.clone(data=df), column_sel)
 
         indexed = cls.indexed(dataset, selection)
         if isinstance(selection_mask, pd.Series):
@@ -438,11 +456,16 @@ class PandasInterface(Interface, PandasAPI):
             data = dataset.data[dim.name]
         if keep_index:
             return data
-        if data.dtype.kind == 'M' and getattr(data.dtype, 'tz', None):
+        if dtype_kind(data) == 'M' and getattr(data.dtype, 'tz', None):
             data = (data if isindex else data.dt).tz_localize(None)
         if not expanded:
             return pd.unique(data)
-        return data.values if hasattr(data, 'values') else data
+        if hasattr(data, 'values'):
+            data = data.values
+            # https://pandas.pydata.org/docs/dev/user_guide/copy_on_write.html#read-only-numpy-arrays
+            if hasattr(data, "flags") and not data.flags.writeable:
+                data = data.copy()
+        return data
 
 
     @classmethod
@@ -480,9 +503,9 @@ class PandasInterface(Interface, PandasAPI):
 
     @classmethod
     def as_dframe(cls, dataset):
-        """
-        Returns the data of a Dataset as a dataframe avoiding copying
+        """Returns the data of a Dataset as a dataframe avoiding copying
         if it already a dataframe type.
+
         """
         if issubclass(dataset.interface, PandasInterface):
             if any(cls.isindex(dataset, dim) for dim in dataset.dimensions()):
