@@ -1,12 +1,9 @@
-from __future__ import absolute_import, division, unicode_literals
-
 import base64
 import logging
 from io import BytesIO
 
-import param
 import bokeh
-
+import param
 from bokeh.document import Document
 from bokeh.io import curdoc
 from bokeh.models import Model
@@ -15,12 +12,11 @@ from panel.io.notebook import render_mimebundle
 from panel.io.state import state
 from param.parameterized import bothmethod
 
-from ...core import Store, HoloMap
+from ...core import HoloMap, Store
 from ..plot import Plot
-from ..renderer import Renderer, MIME_TYPES, HTML_TAGS
+from ..renderer import HTML_TAGS, MIME_TYPES, Renderer
 from .util import compute_plot_size
 
-
 default_theme = Theme(json={
     'attrs': {
         'Title': {'text_color': 'black', 'text_font_size': '12pt'}
@@ -33,11 +29,11 @@ class BokehRenderer(Renderer):
     backend = param.String(default='bokeh', doc="The backend name.")
 
 
-    fig = param.ObjectSelector(default='auto', objects=['html', 'json', 'auto', 'png'], doc="""
+    fig = param.Selector(default='auto', objects=['html', 'json', 'auto', 'png'], doc="""
         Output render format for static figures. If None, no figure
         rendering will occur. """)
 
-    holomap = param.ObjectSelector(default='auto',
+    holomap = param.Selector(default='auto',
                                    objects=['widgets', 'scrubber',
                                             None, 'gif', 'auto'], doc="""
         Output render multi-frame (typically animated) format. If
@@ -47,7 +43,7 @@ class BokehRenderer(Renderer):
                                 allow_None=True, doc="""
        The applicable Bokeh Theme object (if any).""")
 
-    webgl = param.Boolean(default=False, doc="""
+    webgl = param.Boolean(default=True, doc="""
         Whether to render plots with WebGL if available""")
 
     # Defines the valid output formats for each mode.
@@ -59,29 +55,30 @@ class BokehRenderer(Renderer):
 
     @bothmethod
     def _save_prefix(self_or_cls, ext):
-        "Hook to prefix content for instance JS when saving HTML"
-        return
+        """Hook to prefix content for instance JS when saving HTML
 
+        """
+        return
 
     @bothmethod
     def get_plot(self_or_cls, obj, doc=None, renderer=None, **kwargs):
-        """
-        Given a HoloViews Viewable return a corresponding plot instance.
+        """Given a HoloViews Viewable return a corresponding plot instance.
         Allows supplying a document attach the plot to, useful when
         combining the bokeh model with another plot.
+
         """
-        plot = super(BokehRenderer, self_or_cls).get_plot(obj, doc, renderer, **kwargs)
+        plot = super().get_plot(obj, doc, renderer, **kwargs)
         if plot.document is None:
             plot.document = Document() if self_or_cls.notebook_context else curdoc()
-        plot.document.theme = self_or_cls.theme
+        if self_or_cls.theme:
+            plot.document.theme = self_or_cls.theme
         return plot
 
-
     def _figure_data(self, plot, fmt, doc=None, as_script=False, **kwargs):
-        """
-        Given a plot instance, an output format and an optional bokeh
+        """Given a plot instance, an output format and an optional bokeh
         document, return the corresponding data. If as_script is True,
         the content will be split in an HTML and a JS component.
+
         """
         model = plot.state
         if doc is None:
@@ -100,6 +97,7 @@ class BokehRenderer(Renderer):
         logger = logging.getLogger(bokeh.core.validation.check.__file__)
         logger.disabled = True
 
+        data = None
         if fmt == 'gif':
             from bokeh.io.export import get_screenshot_as_png
             from bokeh.io.webdriver import webdriver_control
@@ -140,16 +138,14 @@ class BokehRenderer(Renderer):
             div = tag.format(src=src, mime_type=mime_type, css='')
 
         plot.document = doc
-        if as_script:
+        if as_script or data is None:
             return div
         else:
             return data
 
-
     @classmethod
     def plot_options(cls, obj, percent_size):
-        """
-        Given a holoviews object and a percentage size, apply heuristics
+        """Given a holoviews object and a percentage size, apply heuristics
         to compute a suitable figure size. For instance, scaling layouts
         and grids linearly can result in unwieldy figure sizes when there
         are a large number of elements. As ad hoc heuristics are used,
@@ -159,6 +155,7 @@ class BokehRenderer(Renderer):
         Used by the IPython Notebook display hooks and the save
         utility. Note that this can be overridden explicitly per object
         using the fig_size and size plot options.
+
         """
         obj = obj.last if isinstance(obj, HoloMap) else obj
         plot = Store.registry[cls.backend].get(type(obj), None)
@@ -174,15 +171,14 @@ class BokehRenderer(Renderer):
             options['height'] = int(height)
         return dict(options)
 
-
     @bothmethod
     def get_size(self_or_cls, plot):
-        """
-        Return the display size associated with a plot before
+        """Return the display size associated with a plot before
         rendering to any particular format. Used to generate
         appropriate HTML display.
 
         Returns a tuple of (width, height) in pixels.
+
         """
         if isinstance(plot, Plot):
             plot = plot.state
@@ -191,7 +187,6 @@ class BokehRenderer(Renderer):
                              'and bokeh plot objects.')
         return compute_plot_size(plot)
 
-
     @classmethod
     def load_nb(cls, inline=True):
         cls._loaded = True
