@@ -58,7 +58,7 @@ class TestStoreOptsMethod(ComparisonTestCase):
         """
         The new style introduced in #73
         """
-        data = [zip(range(10),range(10)), zip(range(5),range(5))]
+        data = [zip(range(10),range(10), strict=None), zip(range(5),range(5), strict=None)]
         o = Overlay([Curve(c) for c in data]).opts(
             {'Curve.Curve': {'show_grid': False, 'color':'k'}}
         )
@@ -76,7 +76,7 @@ class TestStoreOptsMethod(ComparisonTestCase):
         """
         Complete specification style.
         """
-        data = [zip(range(10),range(10)), zip(range(5),range(5))]
+        data = [zip(range(10),range(10), strict=None), zip(range(5),range(5), strict=None)]
         o = Overlay([Curve(c) for c in data]).opts(
             {'Curve.Curve': {'show_grid':True, 'color':'b'}})
 
