@@ -3,6 +3,7 @@ Unit tests of Raster elements
 """
 
 import numpy as np
+import pytest
 
 from holoviews.element import HSV, RGB, Curve, Image, QuadMesh, Raster
 from holoviews.element.comparison import ComparisonTestCase
@@ -46,6 +47,16 @@ class TestRGB(ComparisonTestCase):
         rgb = RGB(([0, 1, 2], [0, 1, 2], self.rgb_array))
         self.assertEqual(len(rgb.vdims), 4)
 
+    def test_construct_from_xarray_dataset_with_alpha(self):
+        xr = pytest.importorskip('xarray')
+        xr_dataset = xr.DataArray(
+            data=self.rgb_array,
+            coords={"y": [0, 1, 2], "x": [0, 1, 2], "band": list("RGBA")}
+        ).to_dataset(dim="band")
+        rgb = RGB(xr_dataset)
+        assert str(rgb.alpha_dimension) in xr_dataset.data_vars
+        assert len(rgb.vdims) == 4
+
     def test_construct_from_dict_with_alpha(self):
         rgb = RGB({'x': [1, 2, 3], 'y': [1, 2, 3], ('R', 'G', 'B', 'A'): self.rgb_array})
         self.assertEqual(len(rgb.vdims), 4)
@@ -53,7 +64,7 @@ class TestRGB(ComparisonTestCase):
     def test_not_using_class_variables_vdims(self):
         init_vdims = RGB(self.rgb_array).vdims
         cls_vdims = RGB.vdims
-        for i, c in zip(init_vdims, cls_vdims):
+        for i, c in zip(init_vdims, cls_vdims, strict=None):
             assert i is not c
             assert i == c
 
@@ -78,7 +89,7 @@ class TestHSV(ComparisonTestCase):
     def test_not_using_class_variables_vdims(self):
             init_vdims = HSV(self.hsv_array).vdims
             cls_vdims = HSV.vdims
-            for i, c in zip(init_vdims, cls_vdims):
+            for i, c in zip(init_vdims, cls_vdims, strict=None):
                 assert i is not c
                 assert i == c
 
