@@ -19,11 +19,12 @@ from bokeh.models import (
 
 from holoviews import opts
 from holoviews.core import Dimension, DynamicMap, HoloMap, NdOverlay, Overlay
+from holoviews.core.options import AbbreviatedException
 from holoviews.core.util import dt_to_int
-from holoviews.element import Curve, HeatMap, Image, Labels, Scatter
-from holoviews.plotting.bokeh.util import BOKEH_GE_3_4_0, BOKEH_GE_3_6_0
+from holoviews.element import Curve, HeatMap, Image, Labels, Rectangles, Scatter
+from holoviews.plotting.bokeh.util import BOKEH_GE_3_4_0, BOKEH_GE_3_6_0, BOKEH_GE_3_8_0
 from holoviews.plotting.util import process_cmap
-from holoviews.streams import PointDraw, Stream
+from holoviews.streams import Pipe, PointDraw, Stream
 from holoviews.util import render
 
 from ...utils import LoggingComparisonTestCase
@@ -455,6 +456,12 @@ class TestElementPlot(LoggingComparisonTestCase, TestBokehPlot):
         x_range = plot.handles['x_range']
         self.assertEqual(x_range.factors, [])
 
+    def test_style_map_dimension_object(self):
+        x = Dimension('x')
+        y = Dimension('y')
+        scatter = Scatter([1, 2, 3], kdims=[x], vdims=[y]).opts(color=x)
+        self._test_colormapping(scatter, 'x', prefix='color_')
+
     #################################################################
     # Aspect tests
     #################################################################
@@ -816,6 +823,84 @@ class TestElementPlot(LoggingComparisonTestCase, TestBokehPlot):
             "WARNING", "cb model could not be"
         )
 
+    def test_dynamicmap_subcoordinate_y_enabled_labels_mismatched(self):
+        cases = [  # TODO: pytest.mark.parametrize
+            ("", "", "", "1"),
+            ("", "1", "", "2"),
+            ("", "1", "2", "1"),
+            ("", "1", "2", "3"),
+            ("1", "2", "1", "4"),
+            ("1", "2", "4", "1"),
+            ("1", "2", "3", "4"),
+        ]
+
+        def func(data, plot_labels):
+            if not data:
+                return (
+                        Curve([], label=plot_labels[0]) *
+                        Curve([], label=plot_labels[1])
+                )
+            plot1 = Curve([0, 1], label=plot_labels[2]).opts(subcoordinate_y=True)
+            plot2 = Curve([2, 1], label=plot_labels[3]).opts(subcoordinate_y=True)
+            return plot1 * plot2
+
+        for labels in cases:
+            pipe = Pipe(data=False)
+            dmap = DynamicMap(lambda data, labels=labels: func(data, labels), streams=[pipe])
+            bokeh_renderer.get_plot(dmap)
+
+            msg = 'Failed retrieving "subcoordinate_y". Labels mismatched for initial and updated DynamicMap plots.'
+            with pytest.raises(AbbreviatedException, match=msg):
+                pipe.send(True)
+
+    def test_dynamicmap_subcoordinate_y_enabled_labels_matched(self):
+        cases = [  # TODO: pytest.mark.parametrize
+            ("1", "2", "2", "1"),
+            ("1", "2", "1", "2"),
+        ]
+        def func(data, plot_labels):
+            if not data:
+                return (
+                        Curve([], label=plot_labels[0]) *
+                        Curve([], label=plot_labels[1])
+                )
+            plot1 = Curve([0, 1], label=plot_labels[2]).opts(subcoordinate_y=True)
+            plot2 = Curve([2, 1], label=plot_labels[3]).opts(subcoordinate_y=True)
+            return plot1 * plot2
+
+        for labels in cases:
+            pipe = Pipe(data=False)
+            dmap = DynamicMap(lambda data, labels=labels: func(data, labels), streams=[pipe])
+            bokeh_renderer.get_plot(dmap)
+            # works with no issue
+            pipe.send(True)
+
+    @pytest.mark.skipif(not BOKEH_GE_3_8_0, reason="requires Bokeh >= 3.8")
+    def test_timedelta_axis_polars(self):
+        from bokeh.models.axes import TimedeltaAxis
+        pl = pytest.importorskip("polars")
+        df = pl.DataFrame(
+            {
+                "duration": [1000, 2000, 3000],
+                "data": [1, 2, 3],
+            }
+        ).with_columns(pl.col("duration").cast(pl.Duration("ns")))
+        el = Curve(df)
+        assert isinstance(render(el).below[0], TimedeltaAxis)
+
+    @pytest.mark.skipif(not BOKEH_GE_3_8_0, reason="requires Bokeh >= 3.8")
+    def test_timedelta_axis_pandas(self):
+        from bokeh.models.axes import TimedeltaAxis
+        pd = pytest.importorskip("pandas")
+        df = pd.DataFrame(
+            {
+                "duration": pd.to_timedelta([1000, 2000, 3000]),
+                "data": [1, 2, 3],
+            }
+        )
+        el = Curve(df)
+        assert isinstance(render(el).below[0], TimedeltaAxis)
+
 
 @pytest.mark.usefixtures("bokeh_backend")
 @pytest.mark.skipif(not BOKEH_GE_3_4_0, reason="requires Bokeh >= 3.4")
@@ -904,7 +989,7 @@ class TestScalebarPlot:
         scalebars = [next(sb) if e else None for e in enabled]
         assert sum(map(bool, scalebars)) == sum(enabled)
 
-        for coordinate, scalebar, idx in zip(coordinates, scalebars, "123"):
+        for coordinate, scalebar, idx in zip(coordinates, scalebars, "123", strict=None):
             assert coordinate.y_source.name == f"c{idx}"
             if scalebar is None:
                 continue
@@ -1255,3 +1340,25 @@ class TestApplyHardBounds(TestBokehPlot):
         assert plot.handles['x_range'].start == 2
         assert plot.handles['x_range'].end == 3
         assert plot.handles['x_range'].bounds == (0, 20)
+
+def test_rectangles_colormapping_with_polars():
+    # Test for https://github.com/holoviz/holoviews/issues/6728
+    pl = pytest.importorskip("polars")
+
+    df = pl.DataFrame({
+        'a': [3, 4],
+        'b': [3, 4],
+        'c': [10, 20],
+        'd': [10, 20],
+        'e': [1, 2],
+    })
+    rectangles = Rectangles(df, kdims=['a', 'b', 'c', 'd']).opts(color='e')
+    plot = bokeh_renderer.get_plot(rectangles)
+    glyph_renderer = plot.handles['glyph_renderer']
+    fill_color = glyph_renderer.glyph.fill_color
+
+    assert fill_color['field'] == 'color'
+    assert isinstance(fill_color['transform'], LinearColorMapper)
+
+    color = list(glyph_renderer.data_source.data['color'])
+    assert color == [1, 2]
