@@ -1,8 +1,16 @@
 import numpy as np
 import pandas as pd
-from bokeh.models import FactorRange, HoverTool, Range1d
+import pytest
+from bokeh.models import (
+    FactorRange,
+    HoverTool,
+    Image as bkImage,
+    Range1d,
+    Rect as bkRect,
+)
 
 from holoviews.element import HeatMap, Image, Points
+from holoviews.plotting.bokeh.heatmap import HeatMapPlot
 
 from .test_plot import TestBokehPlot, bokeh_renderer
 
@@ -97,11 +105,15 @@ class TestHeatMapPlot(TestBokehPlot):
         arr = np.array([[0, 1, 2], [3, 4,  5]])
         hm = HeatMap(Image(arr)).opts(invert_axes=True)
         plot = bokeh_renderer.get_plot(hm)
-        xdim, ydim = hm.kdims
-        source = plot.handles['source']
-        self.assertEqual(source.data['zvalues'], hm.dimension_values(2, flat=False).T.flatten())
-        self.assertEqual(source.data['x'], hm.dimension_values(1))
-        self.assertEqual(source.data['y'], hm.dimension_values(0))
+        assert plot._is_contiguous_gridded is True
+        assert isinstance(plot.handles["glyph"], bkImage)
+
+        data = plot.handles['source'].data
+        np.testing.assert_equal(data['image'][0], hm.dimension_values(2, flat=False).T)
+        assert data["x"] == [-0.5]
+        assert data["y"] == [-0.5]
+        assert data["dw"] == [1]
+        assert data["dh"] == [1]
 
     def test_heatmap_dilate(self):
         hmap = HeatMap([('A',1, 1), ('B', 2, 2)]).opts(dilate=True)
@@ -112,20 +124,26 @@ class TestHeatMapPlot(TestBokehPlot):
     def test_heatmap_single_x_value(self):
         hmap = HeatMap(([1], ['A', 'B'], np.array([[1], [2]])))
         plot = bokeh_renderer.get_plot(hmap)
-        cds = plot.handles['cds']
-        self.assertEqual(cds.data['x'], np.array([1, 1]))
-        self.assertEqual(cds.data['y'], np.array(['A', 'B']))
-        self.assertEqual(cds.data['width'], [2.0, 2.0])
-        self.assertEqual(plot.handles['glyph'].height, 1)
+        assert plot._is_contiguous_gridded is True
+        assert isinstance(plot.handles["glyph"], bkImage)
+
+        data = plot.handles['cds'].data
+        assert data['x'] == [0.5]
+        assert data['y'] == [0]
+        assert data["dw"] == [1]
+        assert data["dh"] == [2]
 
     def test_heatmap_single_y_value(self):
         hmap = HeatMap((['A', 'B'], [1], np.array([[1, 2]])))
         plot = bokeh_renderer.get_plot(hmap)
-        cds = plot.handles['cds']
-        self.assertEqual(cds.data['y'], np.array([1, 1]))
-        self.assertEqual(cds.data['x'], np.array(['A', 'B']))
-        self.assertEqual(cds.data['height'], [2.0, 2.0])
-        self.assertEqual(plot.handles['glyph'].width, 1)
+        assert plot._is_contiguous_gridded is True
+        assert isinstance(plot.handles["glyph"], bkImage)
+
+        data = plot.handles['cds'].data
+        assert data['x'] == [0]
+        assert data['y'] == [0.5]
+        assert data["dw"] == [2]
+        assert data["dh"] == [1]
 
     def test_heatmap_alpha_dim(self):
         data = {
@@ -156,3 +174,61 @@ class TestHeatMapPlot(TestBokehPlot):
         np.testing.assert_array_equal(data["X"], df["X"])
         np.testing.assert_array_equal(data["Y"], df["Y"])
         np.testing.assert_array_equal(data["zvalues"], df["Z"])
+
+    def test_heatmap_pandas_multiindex(self):
+        df = pd.DataFrame(
+            data={'C': [5, 2, -1, 5]},
+            index=pd.MultiIndex.from_product([(0, 1), (0, 1)], names=['A', 'B']),
+        )
+        hm = HeatMap(df, ['A', 'B'], 'C')
+        plot = bokeh_renderer.get_plot(hm)
+        data = plot.handles["cds"].data
+        np.testing.assert_array_equal(data['A'], df.index.get_level_values('A'))
+        np.testing.assert_array_equal(data['B'], df.index.get_level_values('B'))
+        np.testing.assert_array_equal(data['zvalues'], df['C'])
+
+    def test_heatmap_gridded_nonequidistant(self):
+        x = np.arange(12)
+        x[4:] += 5
+        y = [chr(65 + i) for i in range(10)]
+        arr = np.ones((10, 12)) * np.arange(12) * np.atleast_2d(np.arange(10)).T
+        hm = HeatMap((x, y, arr))
+
+        plot = bokeh_renderer.get_plot(hm)
+        assert isinstance(plot.handles["glyph"], bkRect)
+
+        data = plot.handles["cds"].data
+        np.testing.assert_array_equal(data["x"], hm.dimension_values("x"))
+        np.testing.assert_array_equal(data["y"], hm.dimension_values("y"))
+        np.testing.assert_array_equal(data["zvalues"], hm.dimension_values("z"))
+
+
+@pytest.mark.parametrize("optimized_gridded", [True, False])
+@pytest.mark.parametrize("style_name", sorted(HeatMapPlot.style_opts))
+def test_heatmap_style_opts(optimized_gridded, style_name):
+    if style_name == 'cmap':
+        style_value = 'viridis'
+    elif 'color' in style_name:
+        style_value = 'red'
+    elif 'alpha' in style_name:
+        style_value = 0.5
+    elif 'width' in style_name:
+        style_value = 2
+    elif style_name in ('visible', 'muted', 'dilate'):
+        style_value = True
+    elif 'dash' in style_name and 'offset' not in style_name:
+        style_value = 'solid'
+    elif 'join' in style_name:
+        style_value = 'miter'
+    elif 'cap' in style_name:
+        style_value = 'butt'
+    elif 'offset' in style_name:
+        style_value = 0
+    else:
+        style_value = 1
+
+    fig = HeatMap(([1,2,3,4], [1,2], [[1,2,3,4], [1,2,3,4]]))
+    styled = fig.opts(optimize_gridded=optimized_gridded, **{style_name: style_value})
+
+    plot = bokeh_renderer.get_plot(styled)
+    assert isinstance(plot.handles["glyph"], bkImage if optimized_gridded else bkRect)
