@@ -2,6 +2,8 @@ import datetime as dt
 
 import numpy as np
 import pandas as pd
+import pytest
+from bokeh.core.enums import MarkerType
 from bokeh.models import (
     CategoricalColorMapper,
     Circle,
@@ -14,7 +16,8 @@ import holoviews as hv
 from holoviews.core import NdOverlay
 from holoviews.core.options import Cycle
 from holoviews.element import Points
-from holoviews.plotting.bokeh.util import property_to_dict
+from holoviews.plotting.bokeh.chart import SizebarMixin
+from holoviews.plotting.bokeh.util import BOKEH_GE_3_8_0, property_to_dict
 from holoviews.streams import Stream
 
 from ..utils import ParamLogStream
@@ -164,6 +167,17 @@ class TestPointPlot(TestBokehPlot):
         fig = plot.state
         self.assertEqual(len(fig.legend), 0)
 
+    def test_native_marker_legend(self):
+        """When one plots with a native bokeh marker, the legend uses that marker."""
+        for marker in MarkerType:
+            with self.subTest(marker=marker):
+                # Plot with a categorical color mapper solely to obtain a legend.
+                points = Points([(0, 0, "A"), (0, 1, "B")], vdims="color").opts(
+                    color="color", marker=marker
+                )
+                plot = bokeh_renderer.get_plot(points)
+                assert plot.state.legend[0].items[0].renderers[0].glyph.marker == marker
+
     def test_points_non_numeric_size_warning(self):
         data = (np.arange(10), np.arange(10), list(map(chr, range(94,104))))
         points = Points(data, vdims=['z']).opts(size_index=2)
@@ -581,3 +595,92 @@ class TestPointPlot(TestBokehPlot):
         handles = bokeh_renderer.get_plot(plot).handles
         glyph = handles["glyph"]
         assert isinstance(glyph, Circle)
+
+
+@pytest.mark.skipif(not BOKEH_GE_3_8_0, reason="Needs Bokeh 3.8")
+class TestSizeBar:
+
+    def setup_method(self):
+        np.random.seed(1)
+        N = 100
+        x = np.random.random(size=N) * 100
+        y = np.random.random(size=N) * 100
+        radii = np.random.random(size=N) * 10
+        self.plot = hv.Points((x, y, radii), vdims=["radii"]).opts(radius="radii")
+
+    def get_handles(self):
+        return bokeh_renderer.get_plot(self.plot).handles
+
+    def get_sizebar(self):
+        return self.get_handles().get("sizebar")
+
+    def test_init(self):
+        from bokeh.models import SizeBar
+
+        assert self.get_sizebar() is None
+
+        self.plot.opts(sizebar=True)
+        assert isinstance(self.get_sizebar(), SizeBar)
+
+    @pytest.mark.parametrize("location", [SizebarMixin.param.sizebar_location.default])
+    def test_location(self, location):
+        self.plot.opts(sizebar=True, sizebar_location=location)
+        handles = self.get_handles()
+        assert handles["sizebar"] in getattr(handles["plot"], location)
+
+    @pytest.mark.parametrize("orientation", [SizebarMixin.param.sizebar_orientation.default])
+    def test_orientation(self, orientation):
+        self.plot.opts(sizebar=True, sizebar_orientation=orientation)
+        assert self.get_sizebar().orientation == orientation
+
+    def test_style(self):
+        self.plot.opts(sizebar=True, sizebar_color="red", sizebar_alpha = 0.1)
+        sizebar = self.get_sizebar()
+        assert sizebar.glyph_fill_alpha == 0.1
+        assert sizebar.glyph_fill_color == "red"
+
+    @pytest.mark.parametrize("bounds", [(0, 10), (0, float("inf"))])
+    def test_bounds(self, bounds):
+        self.plot.opts(sizebar=True, sizebar_bounds=bounds)
+        assert self.get_sizebar().bounds == bounds
+
+    @pytest.mark.parametrize("location", [SizebarMixin.param.sizebar_location.default])
+    @pytest.mark.parametrize("orientation", [SizebarMixin.param.sizebar_orientation.default])
+    @pytest.mark.parametrize("set_width", [True, False])
+    def test_max_size(self, location, orientation, set_width):
+        self.plot.opts(sizebar=True, sizebar_location=location, sizebar_orientation=orientation)
+        if set_width:
+            self.plot.opts(sizebar_opts={"width": 216})  # Using 216 as it will never be a default
+
+        width = self.get_sizebar().width
+        match (location, orientation, set_width):
+            case ("above" | "below", "horizontal", False):
+                assert width == "max"
+            case ("left" | "right", "vertical", False):
+                assert width == "max"
+            case _:
+                if set_width:
+                    assert width == 216
+                else:
+                    assert width != "max"
+
+    def test_overlay(self):
+        # Mainly just to check it does not raise an exception
+        p1 = self.plot.opts(sizebar=True)
+        p2 = hv.Curve([1, 2, 3])
+        combined = p1 * p2
+
+        bk_element = hv.render(combined)
+        assert len(bk_element.renderers) == 2  # the two plots
+        assert len(bk_element.below) == 2  # axis and sizebar
+
+    def test_layout(self):
+        # Mainly just to check it does not raise an exception
+        p1 = self.plot.opts(sizebar=True)
+        p2 = hv.Curve([1, 2, 3])
+        combined = p1 + p2
+
+        bk_element = hv.render(combined)
+        assert len(bk_element.children) == 2
+        assert len(bk_element.children[0][0].below) == 2
+        assert len(bk_element.children[1][0].below) == 1
